{% extends "base.html"%}
{% block content %}
<div class='container mt-4 mb-3'>
    <form method='POST'>
        <div class='mb-3'>
            <label class='form-label'>リポジトリ名</label>
            <input type='text' name='name' class='form-control' value='{{post.name}}'/>
        </div>
        <div class='mb-3'>
            <label class='form-label'>オーナー</label>
            <select class='form-select' name='owner'>
            {% for node in nodes %}
                <option value='{{node._id}}' {% if node._id == post.owner %}selected{% endif %}>{{node.name}}</option>
            {% endfor %}
            </select>
        </div>
        <p>{{error}}</p>
        {{ forms.csrf(request) }}
        <button class='btn btn-primary'>作成</button>
    </form>
</div>
{% endblock %}
