{% extends "base.html"%}
{% block content %}
<div>
    <form method='POST'>
        <h1>{{repo.name}}を削除します</h1>
        <dl>
            <input type='password' name='password' placeholder='パスワード'/>
        </dl>
        <p>{{error}}</p>
        {{ forms.csrf(request) }}
        <button>パスワード</button>
    </form>
</div>
{% endblock %}
