{% extends "repo/base.html" %}
{% block repo %}
    <ul class='nav nav-tabs mt-3 mb-3'>
        <li class='nav-item'>
            <a class='nav-link' href='{{ url('/' + repo.name) }}'>コード</a>
        </li>
        <li class='nav-item'>
            <a class='nav-link' href='{{ url('/' + repo.name + '/log') }}'>ログ</a>
        </li>
        <li class='nav-item'>
            <a class='nav-link' href='{{ url('/' + repo.name + '/merge') }}'>マージ</a>
        </li>
        <li class='nav-item'>
            <a class='nav-link active' href='{{ url('/' + repo.name + '/action') }}'>アクション</a>
        </li>
    </ul>
    <a href='{{ url('/' + repo.name + '/action/create') }}' class='btn btn-primary'>アクションを発動する</a>
    <ul class='list-group mb-3 mt-4'>
        {% if actions %}
        {% for action in actions %}
        <li class='list-group-item'>
            <a href='{{ url('/' + repo.name + '/action/' + action._id) }}'>{{ action.title }}</a>
        </li>
        {% endfor %}
        {% endif %}
    </ul>
{% endblock %}
