{% extends "repo/base.html"%}
{% block repo %}
    <ul class='nav nav-tabs mt-3 mb-3'>
        <li class='nav-item'>
            <a class='nav-link active' href='{{ url('/' + repo.name) }}'>コード</a>
        </li>
        <li class='nav-item'>
            <a class='nav-link' href='{{ url('/' + repo.name + '/log') }}'>ログ</a>
        </li>
        <li class='nav-item'>
            <a class='nav-link' href='{{ url('/' + repo.name + '/merge') }}'>マージ</a>
        </li>
        <li class='nav-item'>
            <a class='nav-link' href='{{ url('/' + repo.name + '/hook') }}'>フック</a>
        </li>
    </ul>
    <div class='card'>
        <div class='card-body'>
            <h5 class='card-title'>{{ name }}</h5>
            <div>
                <pre><code>{{ content }}</code></pre>
            </div>
        </div>
    </div>
{% endblock %}
